CREATE SCHEMA cornac;

CREATE TABLE IF NOT EXISTS cornac.schema_migration_log (
  version TEXT UNIQUE NOT NULL PRIMARY KEY,
  cdate TIMESTAMP DEFAULT NOW()
);
